@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '2.3'
+Version = '2.4'
 
 import os
 import sys
@@ -40,7 +40,7 @@ updateSettings      = 'updateTransitions'             # name of the script used
 
 #############################################################################################################
 
-def checkFile(Path, File):       
+def checkFile(Path, File):
     ''' Check if a file exists. '''
 
     try:
@@ -51,7 +51,7 @@ def checkFile(Path, File):
     else:
        return True
 
-def showMessage(message):        
+def showMessage(message):
     ''' Method to display a message to the user that waits for an action. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
@@ -100,7 +100,7 @@ def checkTactileInstalled():
     else: 
        return False
         
-def getCurrent():   
+def getCurrent(): #FIXME: add new confiVars for version 20.2010.36-maemo16
     '''Read the values currently in the config file'''
      
     if checkFile(PathTheme,ConfigTheme) == True:
@@ -115,7 +115,7 @@ def getCurrent():
     #define variables to readout
     global dataVars
     dataVars={}
-    configVars = ['zoom_on_press', 'parallax', 'blurless', 'taskswitcher', 'zaxisrotation', 'forcerotation', 'tactilepopups']
+    configVars = ['zoom_on_press', 'parallax', 'blurless', 'blurless_saturation', 'taskswitcher', 'zaxisrotation', 'forcerotation', 'tactilepopups']
 
     #readout the variables               
     try:
@@ -335,6 +335,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        try:
           self.ui.comboBoxZoomPress.setCurrentIndex(int(dataVars['zoom_on_press']))
           self.ui.comboBoxBlurless.setCurrentIndex(int(dataVars['blurless']))
+          self.ui.comboBoxBlurlessSaturation.setCurrentIndex(int(dataVars['blurless_saturation']))
           self.ui.comboBoxTaskSwitcher.setCurrentIndex(int(dataVars['taskswitcher']))
           self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
           self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
@@ -354,8 +355,9 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
           DesktopEditor = os.popen('gconftool-2 -g /apps/osso/hildon-desktop/key-actions/disable_edit').read()
           RowsStatusMenu = os.popen('gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows').read()
           RowsStatusMenuPortrait = os.popen('gconftool-2 -g /apps/osso/hildon-status-menu/view/number_of_rows_portrait').read()
+          DesktopScroll = os.popen('gconftool-2 -g /apps/osso/hildon-desktop/scroll_vertical').read()
            
-          #print FMTX, AppMenuEditor, DesktopEditor, RowsStatusMenu, RowsStatusMenuPortrait
+          #print FMTX, AppMenuEditor, DesktopEditor, DesktopScroll, RowsStatusMenu, RowsStatusMenuPortrait
            
           if FMTX == 'false\n':
              self.ui.comboBoxFMTX.setCurrentIndex(0)
@@ -369,6 +371,10 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              self.ui.comboBoxDesktopEditor.setCurrentIndex(0)
           else:   
              self.ui.comboBoxDesktopEditor.setCurrentIndex(1)
+          if DesktopScroll == 'false\n':
+             self.ui.comboBoxDesktopScroll.setCurrentIndex(0)
+          else:   
+             self.ui.comboBoxDesktopScroll.setCurrentIndex(1)
 
           self.ui.doubleSpinBoxRowsStatusMenu.setValue(int(RowsStatusMenu))
           self.ui.doubleSpinBoxRowsStatusMenuPortrait.setValue(int(RowsStatusMenuPortrait))
@@ -381,6 +387,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        '''Set DEFAULT values in the GUI''' 
 
        self.ui.comboBoxBlurless.setCurrentIndex(0)
+       self.ui.comboBoxBlurlessSaturation.setCurrentIndex(0)
        self.ui.comboBoxTaskSwitcher.setCurrentIndex(0)
        self.ui.comboBoxRotationAxis.setCurrentIndex(0)
        self.ui.comboBoxForcedRotation.setCurrentIndex(0)
@@ -390,6 +397,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        self.ui.comboBoxFMTX.setCurrentIndex(0)
        self.ui.comboBoxAppMenuEditor.setCurrentIndex(0)
        self.ui.comboBoxDesktopEditor.setCurrentIndex(0)
+       self.ui.comboBoxDesktopScroll.setCurrentIndex(0)
        self.ui.doubleSpinBoxRowsStatusMenu.setValue(int('6'))
        self.ui.doubleSpinBoxRowsStatusMenuPortrait.setValue(int('8'))
 
@@ -403,13 +411,14 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        showQuickMessage(message)
 
        ##Read GUI.
-       Blurless        = self.ui.comboBoxBlurless.currentIndex()
-       TaskSwitcher    = self.ui.comboBoxTaskSwitcher.currentIndex()
-       RotationAxis    = self.ui.comboBoxRotationAxis.currentIndex()
-       ForcedRotation  = self.ui.comboBoxForcedRotation.currentIndex()
-       Tactile         = self.ui.comboBoxTactile.currentIndex()
-       ZoomPress       = self.ui.comboBoxZoomPress.currentIndex()
-       Parallax        = self.ui.doubleSpinBoxParallax.value()
+       Blurless            = self.ui.comboBoxBlurless.currentIndex()
+       BlurlessSaturation  = self.ui.comboBoxBlurlessSaturation.currentIndex()
+       TaskSwitcher        = self.ui.comboBoxTaskSwitcher.currentIndex()
+       RotationAxis        = self.ui.comboBoxRotationAxis.currentIndex()
+       ForcedRotation      = self.ui.comboBoxForcedRotation.currentIndex()
+       Tactile             = self.ui.comboBoxTactile.currentIndex()
+       ZoomPress           = self.ui.comboBoxZoomPress.currentIndex()
+       Parallax            = self.ui.doubleSpinBoxParallax.value()
 
        if self.ui.comboBoxFMTX.currentIndex() == 0:
           FMTX = 'false'
@@ -423,7 +432,11 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
           DesktopEditor = 'false'
        else:
           DesktopEditor =  'true'
-           
+       if self.ui.comboBoxDesktopScroll.currentIndex() == 0:
+          DesktopScroll = 'false'
+       else:
+          DesktopScroll =  'true'
+          
        RowsStatusMenu = self.ui.doubleSpinBoxRowsStatusMenu.value()
        RowsStatusMenuPortrait = self.ui.doubleSpinBoxRowsStatusMenuPortrait.value()
        
@@ -433,7 +446,8 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        os.system('gconftool-2 -s /apps/osso/hildon-desktop/key-actions/disable_edit -t bool %s' % DesktopEditor)
        os.system('gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows -t int %s' % RowsStatusMenu)
        os.system('gconftool-2 -s /apps/osso/hildon-status-menu/view/number_of_rows_portrait -t int %s' % RowsStatusMenuPortrait)
-
+       os.system('gconftool-2 --set /apps/osso/hildon-desktop/scroll_vertical -t bool %s' % DesktopScroll)
+       
        #Update of the System config file.
        os.rename( PathTemp + ConfigTempSystem, PathTemp + ConfigTempSystem + "~" )
        destination = open( PathTemp + ConfigTempSystem, "w" )
@@ -443,8 +457,10 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              destination.write('zoom_on_press = %s\n' % ZoomPress)
           elif Line.startswith("parallax"):
              destination.write('parallax = %s\n' % Parallax)
-          elif Line.startswith("blurless"):
+          elif Line.startswith("blurless "):
              destination.write('blurless = %s\n' % Blurless)
+          elif Line.startswith("blurless_saturation "):
+             destination.write('blurless_saturation = %s\n' % BlurlessSaturation)
           elif Line.startswith("taskswitcher"):
              destination.write('taskswitcher = %s\n' % TaskSwitcher)
           elif Line.startswith("zaxisrotation"):
@@ -472,8 +488,10 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                 destination.write('zoom_on_press = %s\n' % ZoomPress)
              elif Line.startswith("parallax"):
                 destination.write('parallax = %s\n' % Parallax)
-             elif Line.startswith("blurless"):
+             elif Line.startswith("blurless "):
                 destination.write('blurless = %s\n' % Blurless)
+             elif Line.startswith("blurless_saturation "):
+                destination.write('blurless_saturation = %s\n' % BlurlessSaturation)
              elif Line.startswith("taskswitcher"):
                 destination.write('taskswitcher = %s\n' % TaskSwitcher)
              elif Line.startswith("zaxisrotation"):
@@ -501,7 +519,7 @@ class CSSUfeaturesMain():
        sys.exit(1)
     else:
        pass
-     
+    
     ##Check if CSSU is installed
     if checkCSSUinstalled() == False:
        message = 'ERROR: The Community SSU is not installed.\nSome features might not work correctly..'
